@@ -4,13 +4,8 @@ openapigateway
 
 AWS CDK Construct that creates an Amazon API Gateway HttpApi based on a
 parameterized OpenAPI 3 Document.
-
-Usage
------
-
-Check out the README.md for some usage examples.
 """
 
-__version__ = "0.0.3"
+__version__ = "0.0.4"
 
-from .constructs import OpenApiGateway
+from openapigateway.constructs import OpenApiGateway
